@@ -1,5 +1,6 @@
 package urpm::args;
 
+# $Id: args.pm 271299 2010-11-21 15:54:30Z peroyvind $
 
 use strict;
 use warnings;
@@ -18,7 +19,7 @@ our @EXPORT = '%options';
 
 # Configuration of Getopt. urpmf is a special case, because we need to
 # parse non-alphanumerical options (-! -( -))
-my @configuration = qw(bundling no_ignore_case permute);
+my @configuration = qw(bundling gnu_compat permute);
 push @configuration, 'pass_through'
     if $tool eq 'urpmf' || $tool eq 'urpmi.addmedia';
 Getopt::Long::Configure(@configuration);
@@ -99,7 +100,6 @@ my %options_spec = (
 			 $options{buildrequires} = 1 },
 	'buildrequires' => \$options{buildrequires},
 	'install-src' => \$::install_src,
-	reinstall => sub { $urpm->{options}{reinstall} = 1 },
 	clean => sub { $::clean = 1; $::noclean = 0 },
 	noclean => sub {
 	    $::clean = $urpm->{options}{'pre-clean'} = $urpm->{options}{'post-clean'} = 0;
@@ -367,7 +367,6 @@ my %options_spec = (
 	nopubkey => \$options{nopubkey},
 	raw => \$options{raw},
 	'verify-rpm!' => sub { ${options}{'verify-rpm'} = $_[1] },
-	'ignorearch' => sub { $options{ignorearch} = 1 },
     },
 
 );
@@ -538,6 +537,7 @@ usage:
 
 1;
 
+__END__
 
 =head1 NAME
 
@@ -555,8 +555,6 @@ Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005 MandrakeSoft SA
 
 Copyright (C) 2005-2010 Mandriva SA
 
-Copyright (C) 2011-2020 Mageia
+=cut
 
 =for vim:ts=8:sts=4:sw=4
-
-=cut
