@@ -1,5 +1,6 @@
 package urpm::download;
 
+# $Id: download.pm 271299 2010-11-21 15:54:30Z peroyvind $
 
 use strict;
 use urpm::msg;
@@ -9,9 +10,6 @@ use Cwd;
 use Exporter;
 # perl_checker: require urpm
 
-# help perl_checker:
-sub getcwd { goto &Cwd::getcwd }
-
 our @ISA = 'Exporter';
 our @EXPORT = qw(get_proxy
 	propagate_sync_callback
@@ -75,8 +73,8 @@ my %warned;
 sub preferred_downloader {
     my ($urpm, $medium, $use_metalink) = @_;
 
-    my @available = available_ftp_http_downloaders();
-    my @metalink_downloaders = available_metalink_downloaders();
+    my @available = urpm::download::available_ftp_http_downloaders();
+    my @metalink_downloaders = urpm::download::available_metalink_downloaders();
     my $metalink_disabled = !$$use_metalink && $medium->{disable_metalink};
 
     if ($$use_metalink && !$metalink_disabled) {
@@ -197,7 +195,7 @@ sub get_proxy (;$) {
 	our $PROMPT_PROXY;
 	unless (defined $PROMPT_PROXY) {
 	    require urpm::prompt;
-	    $PROMPT_PROXY = urpm::prompt->new(
+	    $PROMPT_PROXY = new urpm::prompt(
 		N("Please enter your credentials for accessing proxy\n"),
 		[ N("User name:"), N("Password:") ],
 		undef,
@@ -280,7 +278,7 @@ sub set_proxy {
 	if (my ($http_proxy) = $p->{http_proxy} && parse_http_proxy($p->{http_proxy})) {
 	    my $allproxy = $p->{user}; 
 	    $allproxy .= ":" . $p->{pwd} if $p->{pwd}; 
-	    $allproxy .= "@" if $p->{user};
+	    $allproxy .= "@";
 	    $allproxy .= $http_proxy;
 	    @res = ("--all-proxy=http://$allproxy");
 	}
@@ -488,8 +486,8 @@ sub sync_curl {
     #- options for http files, -R (-O <file>)*
     my $result;
     if (my @all_files = (
-	    (map { (_curl_output_option($_), $_) } @ftp_files),
-	    (map { m|/| ? (_curl_output_option($_), $_) : @{[]} } @other_files)))
+	    (map { ("-O", $_) } @ftp_files),
+	    (map { m|/| ? ("-O", $_) : @{[]} } @other_files)))
     {
 	my @l = (@ftp_files, @other_files);
 	my $cmd = join(" ", map { "'$_'" } "/usr/bin/curl",
@@ -516,15 +514,6 @@ sub sync_curl {
     $result;
 }
 
-sub _curl_output_option {
-    my ($remote_file) = @_;
-    #- curl 7.86 changed the -O option to remove any trailing query part from the output
-    #- file name. So if we have a query part, use the -o option instead. If not, use the
-    #- -O option to avoid bloating the command line.
-    my $local_file = basename($remote_file);
-    $local_file =~ /\?/ ? ('-o', $local_file) : '-O';
-}
-
 sub _curl_action {
     my ($cmd, $options, @l) = @_;
     
@@ -549,7 +538,7 @@ sub _curl_action {
 			}
 			#- this checks that download has actually started
 			if ($_ eq "\n"
-			    && !($speed == 0 && $percent == 100 && index($eta, '--') >= 0) #- work around bug 13685
+			    && !($speed eq 0 && $percent == 100 && index($eta, '--') >= 0) #- work around bug 13685
 			) {
 			    propagate_sync_callback($options, 'end', $file);
 			    $file = undef;
@@ -705,7 +694,7 @@ sub sync_aria2 {
 	"/usr/bin/aria2c", $options->{debug} ? ('--log', "$options->{dir}/.aria2.log") : @{[]},
 	'--auto-file-renaming=false',
 	'--ftp-pasv',
-	'--summary-interval=1',
+	'--summary-interval=0',
 	'--follow-metalink=mem',
       $medium->{mirrorlist} ? (
 	'--metalink-enable-unique-protocol=true', # do not try to connect to the same server using the same protocol
@@ -773,29 +762,8 @@ sub _parse_aria2_output {
 				propagate_sync_callback($options, 'start', $file)
 				  if !$options->{is_retry};
 			}
-
-			# aria2c 1.16 and beyond:
-			# parses aria2c: [#2c8dae 496KiB/830KiB(59%) CN:1 DL:84KiB ETA:3s]
-			#
-			# using multiline mode and comments for better readability:
-			#
-			if ($buf =~ m!
-				^\[\#[\dA-Fa-f]+ # match #2c8dae
-				\s+
-				([\d\.]+\w*) # Match 496KiB
-					/
-				([\d\.]+\w*) # Match 830KiB
-				\s* \( (\d+) % \) # Match (59%)
-				\s+
-				CN:(\S+) # Match CN:1
-				\s+
-				DL:(\S+) # Match DL:84KiB
-				\s+
-				ETA:(\w+)
-				\]$
-				!msx
-			)
-			{
+			#parses aria2c: [#1 SIZE:176.0KiB/2.5MiB(6%) CN:3 SPD:256.22KiBs ETA:09s]
+    		    if ($buf =~ m!^\[#\d*\s+\S+:([\d\.]+\w*).([\d\.]+\w*)\S([\d]+)\S+\s+\S+\s*([\d\.]+)\s\w*:([\d\.]+\w*)\s\w*:(\d+\w*)\]$!) {
 			    my ($total, $percent, $speed, $eta) = ($2, $3, $5, $6);
 			    #- $1 = current downloaded size, $4 = connections
 		    if (propagate_sync_callback($options, 'progress', $file, $percent, $total, $eta, $speed) eq 'canceled') {
@@ -848,13 +816,11 @@ END {
 
 #- get the width of the terminal
 my $wchar = 79;
-if (-t *STDOUT) {
-  eval {
+eval {
     require Term::ReadKey;
     ($wchar) = Term::ReadKey::GetTerminalSize();
     --$wchar;
-  };
-}
+};
 
 sub progress_text {
     my ($mode, $percent, $total, $eta, $speed) = @_;
@@ -952,17 +918,10 @@ sub sync_rel {
     my @result_files = map { $all_options->{dir} . '/' . basename($_) } @$rel_files;
     unlink @result_files if $all_options->{preclean};
 
-    #- The files must be world-readable, else mgaapplet and urpm* commands run as
-    #- a normal user won't be able to read them. We enforce umask here in the case
-    #- where the msec security level is set to 'secure' (which means umask 077)
-    #- or where we are run from a gdm-x-session (mga#24636)
-    my $old_umask = umask 0022;
-
     (my $cwd) = getcwd() =~ /(.*)/;
     eval { _sync_webfetch_raw($urpm, $medium, $rel_files, \@files, $all_options) };
     my $err = $@;
     chdir $cwd;
-    umask $old_umask;
     if (!$err) {
 	$urpm->{log}(N("retrieved %s", $files_text));
 	\@result_files;
@@ -1041,7 +1000,7 @@ sub _sync_webfetch_raw {
 	if ($preferred eq 'aria2') {
 	    sync_aria2($urpm, $medium, $rel_files, $options);
 	} else {
-	  my $sync = $urpm::download::{"sync_$preferred"} or die N("no webfetch found, supported webfetch are: %s\n", join(", ", ftp_http_downloaders()));
+	  my $sync = $urpm::download::{"sync_$preferred"} or die N("no webfetch found, supported webfetch are: %s\n", join(", ", urpm::download::ftp_http_downloaders()));
 
 	  my @l = @$files;
 	  while (@l) {
@@ -1129,6 +1088,7 @@ sub _create_metalink_ {
 
 1;
 
+__END__
 
 =back
 
@@ -1138,6 +1098,4 @@ Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005 MandrakeSoft SA
 
 Copyright (C) 2005-2010 Mandriva SA
 
-Copyright (C) 2011-2020 Mageia
-
 =cut
