@@ -1,5 +1,6 @@
 package urpm::install; 
 
+# $Id: install.pm 261966 2009-10-15 11:00:35Z tv $
 
 use strict;
 use urpm;
@@ -21,14 +22,12 @@ urpm::install - Package installation transaction routines for urpmi
 
 # size of the installation progress bar
 my $progress_size = 45;
-if (-t *STDOUT) {
-  eval {
+eval {
     require Term::ReadKey;
     ($progress_size) = Term::ReadKey::GetTerminalSize();
     $progress_size -= 35;
     $progress_size < 5 and $progress_size = 5;
-  };
-}
+};
 
 
 sub _hash_intersect_list {
@@ -94,7 +93,7 @@ See L<URPM> for parameters
 =cut
 
 # install logger callback
-my ($erase_logger, $index, $total_pkg, $uninst_count, $current_pkg, $rpm_version);
+my ($erase_logger, $index, $total_pkg, $uninst_count);
 sub install_logger {
     my ($urpm, $type, undef, $subtype, $amount, $total) = @_;
     local $| = 1;
@@ -113,15 +112,14 @@ sub install_logger {
 	    if ($type eq 'uninst') {
 		$total_pkg = $urpm->{trans}->NElements - $index if !$uninst_count;
 		$cnt = ++$uninst_count;
-		$pname = N("removing %s", $current_pkg);
+		$pname = N("removing %s", $urpm->{trans}->Element_fullname($index));
 		$erase_logger->($urpm, undef, undef, $subtype);
 	    } else {
 		$pname = $urpm->{trans}->Element_name($index);
 		++$urpm->{logger_count} if $pname;
 		$cnt = $pname ? $urpm->{logger_count} : '-';
 	    }
-	    require urpm::select;
-	    $index++ if $rpm_version lt 4.13.0;
+	    $index++;
 	    my $s = sprintf("%9s: %-22s", $cnt . "/" . $total_pkg, $pname);
 	    print $s;
 	    $s =~ / $/ or printf "\n%9s  %-22s", '', '';
@@ -232,8 +230,7 @@ sub _schedule_packages {
 		($true_rpm, $true_pkg) = _apply_delta_rpm($urpm, $mode->{$_}, $mode, $pkg);
 		push @produced_deltas, ($mode->{$_} = $true_rpm); #- fix path
 	    }
-	    if ($urpm->{options}{reinstall} ? $trans->addReinstall($true_pkg || $pkg) :
-	        $trans->add($true_pkg || $pkg, update => $update,
+	    if ($trans->add($true_pkg || $pkg, update => $update,
 		    $options{excludepath} ? (excludepath => [ split /,/, $options{excludepath} ]) : ())) {
 		$urpm->{debug} and $urpm->{debug}(
 		    sprintf('trans: scheduling %s of %s (id=%d, file=%s)', 
@@ -288,28 +285,23 @@ sub _get_callbacks {
 	my ($urpm, undef, undef, $subtype) = @_;
 
 	if ($subtype eq 'start') {
-	    my $name = $trans->Element_name($index);
+	    my ($name, $fullname) = ($trans->Element_name($index), $trans->Element_fullname($index));
 	    my @previous = map { $trans->Element_name($_) } 0 .. ($index - 1);
 	    # looking at previous packages in transaction
 	    # we should be looking only at installed packages, but it should not give a different result
 	    if (member($name, @previous)) {
-		$urpm->{log}("removing upgraded package $current_pkg");
+		$urpm->{log}("removing upgraded package $fullname");
 	    } else {
-		$urpm->{print}(N("removing package %s", $current_pkg)) if $verbose >= 0;
+		$urpm->{print}(N("removing package %s", $fullname)) if $verbose >= 0;
 	    }
 	}
     };
 
     $options->{callback_uninst} ||= $options->{verbose} >= 0 ? \&install_logger : $erase_logger;
 
-    $options->{callback_elem} ||= sub {
-	my (undef, undef, undef, undef, $idx, undef) = @_;
-	$index = $idx;
-	$current_pkg = $trans->Element_fullname($idx);
-    };
     $options->{callback_error} ||= sub {
-	my ($urpm, undef, undef, $subtype, undef, undef) = @_;
-	$urpm->{error}("ERROR: '$subtype' failed for $current_pkg");
+	my ($urpm, undef, $id, $subtype, undef, undef, $fullname) = @_;
+	$urpm->{error}("ERROR: '$subtype' failed for $fullname");
     };
 
     if ($options->{verbose} >= 0 && $have_pkgs) {
@@ -332,20 +324,6 @@ options:
 
 See L<URPM> for callback parameters
 
-There's 2 callbacks that are specific to C<urpm::install> though:
-
-=over
-
-=item * open_helper($data, $type, $id)
-
-=item * close_helper($db, $data, $type, $id)
-
-=back
-
-Those are called when opening/closing a package file, whether when rpmlib verify or install packages.
-
-The C<close_helper> callback receives an extra $db parameter used in eg: drakx to check whether a package really was installed through a DB query.
-
 =cut
 
 #- side-effects: uses a $urpm->{readmes}
@@ -377,11 +355,9 @@ sub install {
     } elsif (!$options{noorder} && (@errors = $trans->order(%options))) {
     } else {
 	$urpm->{readmes} = {};
-	$rpm_version ||= urpm::select::_rpm_version();
 
 	_get_callbacks($urpm, $db, $trans, \%options, $install, $upgrade, scalar @trans_pkgs);
 
-	local $ENV{LD_PRELOAD}; # fix eatmydata & co
 	local $urpm->{trans} = $trans;
 	@errors = $trans->run($urpm, %options);
 	delete $urpm->{trans};
@@ -429,6 +405,6 @@ Copyright (C) 1999-2005 MandrakeSoft SA
 
 Copyright (C) 2005-2010 Mandriva SA
 
-Copyright (C) 2011-2020 Mageia
+Copyright (C) 2011-2013 Mageia
 
 =cut
