@@ -1,10 +1,11 @@
 package urpm::orphans;
 
 use strict;
-use urpm::util qw(add2hash_ append_to_file cat_ member output_safe partition put_in_hash uniq wc_l);
+use urpm::util qw(add2hash_ append_to_file cat_ output_safe partition put_in_hash uniq wc_l);
 use urpm::msg;
 use urpm;
 
+# $Id: select.pm 243120 2008-07-01 12:24:34Z pixel $
 
 my $fullname2name_re = qr/^(.*)-[^\-]*-[^\-]*\.[^\.\-]*$/;
 
@@ -48,12 +49,6 @@ sub unrequested_list__file {
     ($urpm->{env_dir} || "$urpm->{root}/var/lib/rpm") . '/installed-through-deps.list';
 }
 
-=item unrequested_list($urpm)
-
-Returns the list of potentiel files (ake files installed as requires for others)
-
-=cut
-
 #- side-effects: none
 sub unrequested_list {
     my ($urpm) = @_;
@@ -94,20 +89,6 @@ sub mark_as_requested {
     }
 }
 
-=item _installed_req_and_unreq($urpm)
-
-Returns :
-
-=over
-
-=item * req: list of installed packages that were installed as requires of others 
-
-=item * unreq: list of installed packages that were not installed as requres of others (ie the ones that were explicitely selected for install)
-
-=back
-
-=cut
-
 #- side-effects:
 #-   + those of _installed_req_and_unreq_and_update_unrequested_list (<root>/var/lib/rpm/installed-through-deps.list)
 sub _installed_req_and_unreq {
@@ -116,20 +97,6 @@ sub _installed_req_and_unreq {
     ($req, $unreq);
 }
 
-=item _installed_and_unrequested_lists($urpm)
-
-Returns :
-
-=over
-
-=item * pkgs: list of installed packages
-
-=item * unrequested: list of packages that were installed as requires of others (the sum of the previous lists)
-
-=back
-
-=cut
-
 #- side-effects:
 #-   + those of _installed_req_and_unreq_and_update_unrequested_list (<root>/var/lib/rpm/installed-through-deps.list)
 sub _installed_and_unrequested_lists {
@@ -151,22 +118,6 @@ sub _write_unrequested_list__file {
 		".old") if !$urpm->{env_dir};
 }
 
-=item _installed_req_and_unreq_and_update_unrequested_list ($urpm)
-
-Returns :
-
-=over
-
-=item * req: list of installed packages that were installed as requires of others 
-
-=item * unreq: list of installed packages that were not installed as requres of others (ie the ones that were explicitely selected for install)
-
-=item * unrequested: list of packages that were installed as requires of others (the sum of the previous lists)
-
-=back
-
-=cut
-
 #- side-effects: those of _write_unrequested_list__file
 sub _installed_req_and_unreq_and_update_unrequested_list {
     my ($urpm) = @_;
@@ -187,13 +138,9 @@ sub _installed_req_and_unreq_and_update_unrequested_list {
     ($req, $unreq, $unrequested);
 }
 
-=item _selected_unrequested($urpm, $selected, $rejected)
-
-Returns the new "unrequested" packages.
-The reason can be "required by xxx" or "recommended"
-
-=cut
-
+#- returns the new "unrequested" packages
+#- the reason can be "required by xxx" or "recommended"
+#-
 #- side-effects: none
 sub _selected_unrequested {
     my ($urpm, $selected, $rejected) = @_;
@@ -213,12 +160,8 @@ sub _selected_unrequested {
     } keys %$selected;
 }
 
-=item _renamed_unrequested($urpm, $selected, $rejected)
-
-Returns the packages obsoleting packages marked "unrequested"
-
-=cut
-
+#- returns the packages obsoleting packages marked "unrequested"
+#- 
 #- side-effects: none
 sub _renamed_unrequested {
     my ($urpm, $selected, $rejected) = @_;
@@ -336,15 +279,11 @@ sub _unrequested_orphans_after_remove_once {
     0;
 }
 
-=item _will_package_be_unneeded($urpm, $db, $toremove, $pkg)
-
-Return true if $pkg will no more be required after removing $toremove
-
-nb: it may wrongly return false for complex loops,
-but will never wrongly return true
-
-=cut
-
+#- return true if $pkg will no more be required after removing $toremove
+#-
+#- nb: it may wrongly return false for complex loops,
+#-     but will never wrongly return true
+#-
 #- side-effects: none
 sub _will_package_be_unneeded {
     my ($urpm, $db, $toremove, $pkg) = @_;
@@ -375,12 +314,8 @@ sub _will_package_be_unneeded {
     1;
 }
 
-=item _will_prop_still_be_needed($urpm, $db, $toremove, $fullname, $prop, $required_maybe_loop)
-
-Return true if $prop will still be required after removing $toremove
-
-=cut
-
+#- return true if $prop will still be required after removing $toremove
+#-
 #- side-effects: none
 sub _will_prop_still_be_needed {
     my ($urpm, $db, $toremove, $fullname, $prop, $required_maybe_loop) = @_;
@@ -408,63 +343,29 @@ sub _will_prop_still_be_needed {
     });
 }
 
-=item _get_current_kernel_package()
-
-Return the current kernel's package so that we can filter out current running
-kernel:
-
-=cut
-
+# so that we can filter out current running kernel:
 sub _get_current_kernel_package() {
     my $release = (POSIX::uname())[2];
     # --qf '%{name}' is used in order to provide the right format:
     -e "/boot/vmlinuz-$release" && ($release, `rpm -qf --qf '%{name}' /boot/vmlinuz-$release`);
 }
 
-=item _replace_kernel_by_its_provide($urpm, $pkg)
 
-Take a dep, replace it by the pkg providing it.
-Eg:
-Return the current kernel's package so that we can filter out current running
-kernel:
-
-On mdv & mga[1-8], it's for getting the fullname of the matching pkg.
-Eg: kernel-desktop-5.15.45-1.mga8 -> kernel-desktop-5.15.45-1.mga8-1-1.x86_64
-
-On mga9+:
-We've "kernel-desktop[== 5.15.45-1]", we want to find pkg providing that, eg the NVRA of the pkg named 'kernel-desktop' whose version matches.
-
-=cut
-
-sub _replace_kernel_by_its_provide {
-    my ($urpm, $pkg) = @_;
-    my ($req) = grep { /^kernel/ } $pkg->requires;
-    my @a = $urpm->find_candidate_packages($req);
-    $a[0];
-}
-
-=item _kernel_callback ($pkg, $unreq_list)
-
-Returns list of kernels
-
-_fast_ version w/o looking at all non kernel packages requires on
-kernels (like "urpmi_find_leaves '^kernel'" would)
-
-_all_unrequested_orphans blacklists nearly all kernels b/c of packages
-like 'ndiswrapper' or 'basesystem' that requires 'kernel' (on mga < 9)
-
-rationale: other packages only require 'kernel' or a sub package we
-do not care about (eg: kernel-devel, kernel-firmware, kernel-latest)
-so it's useless to look at them
-
-=cut
-
-# @req_by_latest_kernels tracks kernels needed by kernel*-latest
-# %requested_kernels tracks which pkgs requires which kernel pkg
-# %kernels tracks !"*-latest" kernels (to be later filtered)
+# - returns list of kernels
+#
+# _fast_ version w/o looking at all non kernel packages requires on
+# kernels (like "urpmi_find_leaves '^kernel'" would)
+#
+# _all_unrequested_orphans blacklists nearly all kernels b/c of packages
+# like 'ndiswrapper' or 'basesystem' that requires 'kernel'
+#
+# rationale: other packages only require 'kernel' or a sub package we
+# do not care about (eg: kernel-devel, kernel-firmware, kernel-latest)
+# so it's useless to look at them
+#
 my (@req_by_latest_kernels, %requested_kernels, %kernels);
 sub _kernel_callback { 
-    my ($urpm, $pkg, $unreq_list) = @_;
+    my ($pkg, $unreq_list) = @_;
     my $shortname = $pkg->name;
     my $n = $pkg->fullname;
 
@@ -478,27 +379,21 @@ sub _kernel_callback {
     }
 
     # only consider real kernels (and not kernel-doc and the like):
-    return if $shortname =~ /-(?:source|doc|headers|firmware(?:|-extra|-nonfree))$/;
+    return if $shortname =~ /-(?:source|doc|headers|firmware(?:|-extra))$/;
 
     # ignore requested kernels (aka that are not in /var/lib/rpm/installed-through-deps.list)
     return if !$unreq_list->{$shortname} && $shortname !~ /latest/;
 
     # keep track of packages required by latest kernels in order not to try removing requested kernels:
     if ($n =~ /latest/) {
-        my $kpkg = _replace_kernel_by_its_provide($urpm, $pkg);
-        push @req_by_latest_kernels, scalar $kpkg->fullname if $kpkg;
+        push @req_by_latest_kernels, $pkg->requires;
     } else {
-        $kernels{$n} = $pkg;
+        $kernels{$shortname} = $pkg;
     }
 }
 
 
-=item _get_orphan_kernels()
-
-Returns list of orphan kernels
-
-=cut
-
+# - returns list of orphan kernels
 sub _get_orphan_kernels() {
     # keep kernels required by kernel-*-latest:
     delete $kernels{$_} foreach @req_by_latest_kernels;
@@ -507,49 +402,29 @@ sub _get_orphan_kernels() {
 }
 
 
-=item _all_unrequested_orphans($urpm, $req, $unreq)
-
-Returns the list of "unrequested" orphans.
-
-=cut
-
+#- returns the list of "unrequested" orphans.
+#-
 #- side-effects: none
 sub _all_unrequested_orphans {
     my ($urpm, $req, $unreq) = @_;
 
     my (%l, %provides);
-    # 1- list explicit provides (not files) from installed packages:
-
-    my $need_expand = 0;
     foreach my $pkg (@$unreq) {
-	$l{$pkg->fullname} = $pkg;
-	my $n = $pkg->name;
-	# Instead of hardcoding desktop/linus/server/... flavors, blacklist:
-	$need_expand++ if $n =~ /^kernel-(\w+)$/ && !member($1, qw(doc firmware source));
+	$l{$pkg->name} = $pkg;
 	push @{$provides{$_}}, $pkg foreach $pkg->provides_nosense;
     }
     my $unreq_list = unrequested_list($urpm);
 
-    # we need to replace/augment eg "kernel-desktop" by the "kernel-desktop-V-R" for each installed kernel:
-    if ($need_expand) {
-	$kernels{$_->fullname} = $_ foreach grep { /^kernel/ } @$unreq;
-    }
-
     my ($current_kernel_version, $current_kernel) = _get_current_kernel_package();
 
-    # 2- check if "unrequested" packages are still needed:
     while (my $pkg = shift @$req) {
         # do not do anything regarding kernels if we failed to detect the running one (ie: chroot)
-	_kernel_callback($urpm, $pkg, $unreq_list) if $current_kernel;
+ 	_kernel_callback($pkg, $unreq_list) if $current_kernel;
 	foreach my $prop ($pkg->requires, $pkg->recommends_nosense) {
 	    my $n = URPM::property2name($prop);
 	    foreach my $p (@{$provides{$n} || []}) {
-		# FIXME: hackish in order to fix orphaning kernels with virtualbox installed on mga9+
-		# TODO: check if something else that's not orphaned still provides it instead
-		next if $n eq 'kmod(vboxdrv.ko)';
-		my $pfn = $p->fullname;
-		if ($p != $pkg && $l{$pfn} && $p->provides_overlap($prop)) {
-		    delete $l{$pfn};
+		if ($p != $pkg && $l{$p->name} && $p->provides_overlap($prop)) {
+		    delete $l{$p->name};
 		    push @$req, $p;
 		}
 	    }
@@ -612,8 +487,6 @@ Returns the list of unrequested packages (aka orphans).
 It is quite fast. the slow part is the creation of
 $installed_packages_packed (using installed_packages_packed())
 
-Used by C<urpmq --auto_orphans>
-
 =cut
 
 #
@@ -726,6 +599,6 @@ sub installed_leaves {
 
 Copyright (C) 2008-2010 Mandriva SA
 
-Copyright (C) 2011-2020 Mageia
+Copyright (C) 2011-2013 Mageia
 
 =cut
